@@ -35,12 +35,12 @@ class DateTools(object):
         return now.strftime(fmt)
 
     @staticmethod
-    def get_days_date_before(days=31, fmt="%Y-%m-%d %H:%M:%S") -> str:
+    def get_days_date_before(days=31, fmt="%Y-%m-%d") -> str:
         """获取前几天的日期
 
         Args:
             days (int, optional): 前n天. Defaults to 31.
-            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d %H:%M:%S".
+            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d".
 
         Returns:
             str: 格式化后的日期
@@ -49,12 +49,12 @@ class DateTools(object):
         return time_data.strftime(fmt)
 
     @staticmethod
-    def get_days_date_after(days=31, fmt="%Y-%m-%d %H:%M:%S") -> str:
+    def get_days_date_after(days=31, fmt="%Y-%m-%d") -> str:
         """获取后几天的日期
 
         Args:
             days (int, optional): 后n天. Defaults to 31.
-            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d %H:%M:%S".
+            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d".
 
         Returns:
             str: 格式化后的日期
@@ -63,11 +63,11 @@ class DateTools(object):
         return time_data.strftime(fmt)
 
     @staticmethod
-    def get_yesterday_date(fmt="%Y-%m-%d %H:%M:%S") -> str:
+    def get_yesterday_date(fmt="%Y-%m-%d") -> str:
         """获取昨天的日期
 
         Args:
-            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d %H:%M:%S".
+            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d".
 
         Returns:
             str: 格式化后的日期
@@ -75,11 +75,11 @@ class DateTools(object):
         return DateTools.get_days_date_before(days=1, fmt=fmt)
 
     @staticmethod
-    def get_tomorrow_date(fmt="%Y-%m-%d %H:%M:%S") -> str:
+    def get_tomorrow_date(fmt="%Y-%m-%d") -> str:
         """获取明天的日期
 
         Args:
-            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d %H:%M:%S".
+            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d".
 
         Returns:
             str: 格式化后的日期
@@ -87,11 +87,11 @@ class DateTools(object):
         return DateTools.get_days_date_after(days=1, fmt=fmt)
 
     @staticmethod
-    def get_week_before(fmt="%Y-%m-%d %H:%M:%S") -> str:
+    def get_week_before(fmt="%Y-%m-%d") -> str:
         """获取一周前的日期
 
         Args:
-            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d %H:%M:%S".
+            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d".
 
         Returns:
             str: 格式化后的日期
@@ -99,11 +99,11 @@ class DateTools(object):
         return DateTools.get_days_date_before(days=7, fmt=fmt)
 
     @staticmethod
-    def get_week_after(fmt="%Y-%m-%d %H:%M:%S") -> str:
+    def get_week_after(fmt="%Y-%m-%d") -> str:
         """获取一周后的日期
 
         Args:
-            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d %H:%M:%S".
+            fmt (str, optional): 日期格式. Defaults to "%Y-%m-%d".
 
         Returns:
             str: 格式化后的日期
